package at.kugel.tool.buildtray;

import java.awt.AWTException;
import java.awt.Image;
import java.awt.SplashScreen;
import java.awt.SystemTray;
import java.awt.Toolkit;
import java.util.Date;
import java.util.EnumMap;
import java.util.Timer;
import java.util.TimerTask;
import java.io.IOException;

import at.kugel.tool.buildtray.status.Status;
import at.kugel.tool.buildtray.status.SetStatusAble;
import at.kugel.tool.buildtray.action.HtmlRegularExpressionActions;
import at.kugel.tool.buildtray.action.Actions;
import at.kugel.tool.buildtray.config.Config;

/**
 * Loads images display the tray, start polling threads and close splash screen.
 */
public final class Main {

   public static void main(String[] pArgs) throws AWTException, InterruptedException, IOException {
      if (!SystemTray.isSupported()) {
         System.out.println("System Tray not supported");
         System.exit(1);
      }

      final Config conf = new Config(pArgs.length > 0 ? pArgs[0] : null);

      final Actions actions = new HtmlRegularExpressionActions(conf);

      final EnumMap<Status, Image> imgs = new EnumMap<Status, Image>(Status.class);
      imgs.put(Status.OK, Toolkit.getDefaultToolkit().getImage(ClassLoader.getSystemResource("res/build_green.gif")));
      imgs.put(Status.BUSY, Toolkit.getDefaultToolkit().getImage(ClassLoader.getSystemResource("res/build_white.gif")));
      imgs.put(Status.FAILED, Toolkit.getDefaultToolkit().getImage(ClassLoader.getSystemResource("res/build_red.gif")));
      final SetStatusAble tray = new Tray(imgs, actions);

      final Timer timer = new Timer("Build Server Polling", true);
      timer.scheduleAtFixedRate(new TimerTask() {
         @Override
         public void run() {
            actions.refresh(tray);
         }
      }, new Date(), conf.getPollingMs());

      final SplashScreen screen = SplashScreen.getSplashScreen();
      if (screen != null) {
         Thread.sleep(conf.getSplashWaitMs());
         screen.close();
      }
   }

}
