package at.kugel.tool.buildtray;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Frame;
import java.awt.Label;
import java.awt.SystemTray;
import java.awt.TextArea;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

/**
 * Simulate a system tray popup which closes on clicked. Used because older versions of Java 6 do not provide this in
 * Windows systems.
 */
class TrayPopup extends Frame {

   private static final Color FG_COLOR = Color.BLACK;
   private static final Color BG_COLOR = new Color(255, 255, 220);
   private static final String FONT_NAME = "Arial";

   private final Label title = new Label();
   private final TextArea message = new TextArea("", 1, 1, TextArea.SCROLLBARS_NONE);

   public TrayPopup() {
      setUndecorated(true);
      setResizable(false);
      setAlwaysOnTop(true);
      setFocusableWindowState(false);
      addListener(this);

      setLayout(new BorderLayout());

      addListener(title);
      title.setAlignment(Label.CENTER);
      title.setFont(new Font(FONT_NAME, Font.BOLD, 12));
      add(title, BorderLayout.NORTH);

      addListener(message);
      message.setEditable(false);
      add(message, BorderLayout.CENTER);
   }

   void close() {
      setVisible(false);
      dispose();
   }

   private void addListener(Component pComponent) {
      pComponent.setFocusable(false);
      pComponent.addMouseListener(new MouseAdapter() {
         @Override
         public void mouseClicked(MouseEvent pE) {
            close();
         }
      });
      pComponent.setBackground(BG_COLOR);
      pComponent.setForeground(FG_COLOR);
      pComponent.setFont(new Font(FONT_NAME, Font.PLAIN, 10));
   }

   void displayMessage(String pCaption, String pText) {
      title.setText(pCaption);
      final String[] lines = pText.split("\n");
      message.setRows(lines.length);
      message.setColumns(1);
      for (final String l : lines) {
         if (l.length() > message.getColumns()) {
            message.setColumns(l.length());
         }
      }
      message.setText(pText);
      pack();
      final Dimension size = getSize();
      final Dimension screenSize = getToolkit().getScreenSize();
      setLocation(screenSize.width - size.width, screenSize.height - size.height - SystemTray.getSystemTray().getTrayIconSize().height - 4);
      setVisible(true);
   }

   //   public static void main(String[] args)
   //   {
   //      new TrayPopup().displayMessage("Header", "Message\r\nBlabla\nbubu");
   //   }
}
