package at.kugel.tool.buildtray.action;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

/**
 * Helper for String related IO methods.
 */
class StringIOHelper {

   /**
    * Load a textfile from the net into a string.
    * @param pUrl the url to load.
    * @return a string of the file loaded.
    * @throws IOException if the string can not be read.
    */
   public String readNet(URL pUrl) throws IOException {
      final URLConnection con = pUrl.openConnection();
      con.connect();

      int size = con.getContentLength();
      boolean sizeGiven = true;
      if (size < 0) {
         sizeGiven = false;
         // guess size
         size = 256 * 1024;
      }
      final byte[] data = new byte[size];

      InputStream ins = null;
      try {
         ins = con.getInputStream();
         // comes in parts - read parts
         int pos = 0;
         int res = 1;
         while (pos < size && res > 0) {
            res = ins.read(data, pos, size - pos);
            pos += res;
         }

         if (sizeGiven && pos < size) {
            throw new IOException("short file: length=" + pos + " != content-length=" + size);
         } else if (!sizeGiven && pos == size) {
            throw new IOException("possibly long file: length=" + pos + " != content-length=unknown");
         } else if (!sizeGiven) {
            pos++;
         }

         final String encoding = con.getContentEncoding();
         if (encoding == null) {
            return new String(data, 0, pos);
         }

         return new String(data, 0, pos, encoding);

      } finally {
         if (ins != null) {
            ins.close();
         }
      }
   }

}
