package at.kugel.tool.buildtray.config;

import java.io.IOException;
import java.io.FileReader;
import java.util.Properties;

/**
 * Configuration for the tray.
 */
public final class Config {
   private final int splashWaitMs;

   private final long pollingMs;
   private String serverlUrl;

   private final boolean checkBusy;
   private final String busyPattern;
   private final int busyPatternNameGroup;

   private final String successValue;
   private final String failedValue;

   private final String statusPattern;
   private final int statusPatternNameGroup;
   private final int statusPatternStatusGroup;
   private final int statusPatternDateGroup;
   private final String datePattern;

   public Config(String pPath) throws IOException {
      if (pPath == null) {
         throw new IllegalArgumentException("path is null");
      }
      Properties props = new Properties();
      props.load(new FileReader(pPath));

      splashWaitMs = Integer.parseInt(props.getProperty("splash.wait.ms"));
      pollingMs = Integer.parseInt(props.getProperty("polling.ms"));
      serverlUrl = props.getProperty("server.url");
      checkBusy = Boolean.valueOf(props.getProperty("busy.check"));
      busyPattern = props.getProperty("busy.pattern");
      busyPatternNameGroup = Integer.parseInt(props.getProperty("busy.name.group"));
      successValue = props.getProperty("value.success");
      failedValue = props.getProperty("value.failed");
      statusPattern = props.getProperty("status.pattern");
      statusPatternNameGroup = Integer.parseInt(props.getProperty("status.name.group"));
      statusPatternStatusGroup = Integer.parseInt(props.getProperty("status.value.group"));
      statusPatternDateGroup = Integer.parseInt(props.getProperty("status.date.group"));
      datePattern = props.getProperty("status.date.format");
   }

   public long getPollingMs() {
      return pollingMs;
   }

   public String getServerlUrl() {
      return serverlUrl;
   }

   public void setServerlUrl(String pServerlUrl) {
      serverlUrl = pServerlUrl;
   }

   public boolean isCheckBusy() {
      return checkBusy;
   }

   public String getDatePattern() {
      return datePattern;
   }

   public long getSplashWaitMs() {
      return splashWaitMs;
   }

   public String getBusyPattern() {
      return busyPattern;
   }

   public String getSuccessValue() {
      return successValue;
   }

   public String getFailedValue() {
      return failedValue;
   }

   public String getStatusPattern() {
      return statusPattern;
   }

   public int getBusyPatternNameGroup() {
      return busyPatternNameGroup;
   }

   public int getStatusPatternNameGroup() {
      return statusPatternNameGroup;
   }

   public int getStatusPatternStatusGroup() {
      return statusPatternStatusGroup;
   }

   public int getStatusPatternDateGroup() {
      return statusPatternDateGroup;
   }
}
